.. currentmodule:: pandas_indexing

#############
API reference
#############

This page provides an auto-generated summary of pandas-indexing's API. For more details
and examples, refer to the relevant chapters in the main part of the documentation.


core
====

.. automodule:: pandas_indexing.core
    :members:


accessors
=========

.. automodule:: pandas_indexing.accessors
    :members:


arithmetics
===========

.. automodule:: pandas_indexing.arithmetics
    :members:


selectors
=========

.. automodule:: pandas_indexing.selectors
    :members:


units
=====

.. automodule:: pandas_indexing.units
    :members:
